[][src]Crate substrate_browser_utils

Structs

Client

A running client.

ExtTransport

Implementation of Transport whose implementation is handled by some FFI.

Transport

Type of the object that allows opening connections.

Functions

browser_configuration

Create a service configuration from a chain spec and the websocket transport.

init_console_log

Initializes the global logger setting max_log_level to the given value.

set_console_error_panic_hook

Set the console.error panic hook the first time this is called. Subsequent invocations do nothing.

start_client

Create a Client object that connects to a service.