[−]Struct substrate_browser_utils::Transport
Type of the object that allows opening connections.
Methods
impl Transport
pub fn dial(&self, multiaddr: &str) -> Result<Promise, JsValue>
Start attempting to dial the given multiaddress.
The returned Promise must yield a [Connection] on success.
If the multiaddress is not supported, you should return an instance of Error whose
name property has been set to the string "NotSupportedError".
impl Transport
pub fn listen_on(&self, multiaddr: &str) -> Result<Iterator, JsValue>
Start listening on the given multiaddress.
The returned Iterator must yield Promises to [ListenEvent] events.
If the multiaddress is not supported, you should return an instance of Error whose
name property has been set to the string "NotSupportedError".
Methods from Deref<Target = JsValue>
pub const NULL: JsValue[src]
pub const UNDEFINED: JsValue[src]
pub const TRUE: JsValue[src]
pub const FALSE: JsValue[src]
pub fn as_f64(&self) -> Option<f64>[src]
Returns the f64 value of this JS value if it's an instance of a
number.
If this JS value is not an instance of a number then this returns
None.
pub fn is_string(&self) -> bool[src]
Tests whether this JS value is a JS string.
pub fn as_string(&self) -> Option<String>[src]
If this JS value is a string value, this function copies the JS string
value into wasm linear memory, encoded as UTF-8, and returns it as a
Rust String.
To avoid the copying and re-encoding, consider the
JsString::try_from() function from js-sys
instead.
If this JS value is not an instance of a string or if it's not valid
utf-8 then this returns None.
UTF-16 vs UTF-8
JavaScript strings in general are encoded as UTF-16, but Rust strings
are encoded as UTF-8. This can cause the Rust string to look a bit
different than the JS string sometimes. For more details see the
documentation about the str type which contains a few
caveats about the encodings.
pub fn as_bool(&self) -> Option<bool>[src]
Returns the bool value of this JS value if it's an instance of a
boolean.
If this JS value is not an instance of a boolean then this returns
None.
pub fn is_null(&self) -> bool[src]
Tests whether this JS value is null
pub fn is_undefined(&self) -> bool[src]
Tests whether this JS value is undefined
pub fn is_symbol(&self) -> bool[src]
Tests whether the type of this JS value is symbol
pub fn is_object(&self) -> bool[src]
Tests whether typeof self == "object" && self !== null.
pub fn is_function(&self) -> bool[src]
Tests whether the type of this JS value is function.
pub fn is_truthy(&self) -> bool[src]
Tests whether the value is "truthy".
pub fn is_falsy(&self) -> bool[src]
Tests whether the value is "falsy".